Learn R Programming

mecor (version 0.9.0)

eovs: External Outcome-Validation Study

Description

A simulated dataset containing 100 observations of the gold standard measurement of outcome Y and the error-prone outcome Y_star. The covariates X and Z are not observed in the study population. To be used in combination with the dataset iovs.

Usage

eovs

Arguments

Format

A data frame with 100 rows and 2 variables:

Y

gold standard outcome, continuous

Y_star

error-prone outcome, continuous

Examples

Run this code
# NOT RUN {
data("eovs", package = "mecor")
# }

Run the code above in your browser using DataLab