powered by
A simulated dataset containing 100 observations of the gold standard measurement of outcome Y and the error-prone outcome Y_star. The covariates X and Z are not observed in the study population. To be used in combination with the dataset iovs.
eovs
A data frame with 100 rows and 2 variables:
gold standard outcome, continuous
error-prone outcome, continuous
# NOT RUN { data("eovs", package = "mecor") # }
Run the code above in your browser using DataLab